our $VERSION = '0.10';

1;

=head1 NAME

Foo::Bar - Best Foo module ever

=head1 SYNOPSIS

...

=head1 DESCRIPTION

...

=head1 AUTHOR

Ingy döt Net <ingy@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright 2012-2014. Ingy döt Net.

This program is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

See http://www.perl.com/perl/misc/Artistic.html

=cut

